==> OpenResearchMigration-0.0.3.tar.gz: OpenResearchMigration-0.0.3/README.md <==
[![Join the discussion](https://img.shields.io/badge/Discussion-OPENRESEARCH-brightgreen)](https://github.com/SmartDataAnalytics/OpenResearch/discussions)
[![GitHub issues](https://img.shields.io/github/issues/SmartDataAnalytics/OpenResearch.svg)](https://github.com/SmartDataAnalytics/OpenResearch/issues)
[![GitHub issues](https://img.shields.io/github/issues-closed/SmartDataAnalytics/OpenResearch.svg)](https://github.com/SmartDataAnalytics/OpenResearch/issues/?q=is%3Aissue+is%3Aclosed)
[![Website OPENRESEARCH](https://img.shields.io/website-up-down-green-red/https/www.openresearch.org.svg)](https://www.openresearch.org)
# OPEN RESEARCH

This repository is mainly used as public ticket system for
[![OPENRESEARCH LOGO](https://www.openresearch.org/mediawiki/images/e/ed/Openresearch_logo_2017_rgb_resized.png)](https://www.openresearch.org/wiki/Main_Page)


# ConfIDent
[![ConfIDent Logo](https://projects.tib.eu/fileadmin/templates/confident/tib_projects_confident_1150.jpg)](https://www.openresearch.org)

## Public Links
* [OPENRESEARCH](https://www.openresearch.org)
* [ConfIDent Project Home page](https://projects.tib.eu/en/confident/)
* [ConfIDent Project page at TIB](https://www.tib.eu/en/research-development/project-overview/project-summary/confident)
* [RWTH Aachen i5 ConfIDent server](https://confident.dbis.rwth-aachen.de/)
* [TIB confident-conference.org](https://www.confident-conference.org/r/)

## Demos
* [Proceedings Title Parser](http://ptp.bitplan.com)
* [Semantified CEUR-WS](http://ceur-ws.bitplan.com/index.php/Main_Page)
* [Conferences and Location demo](https://cr.bitplan.com/index.php/Main_Page)
* [dblp xml conference import](https://confident.dbis.rwth-aachen.de/dblpconf/)

## Protected content
* [ConfIDent Requirements, Usecases and Design](https://rq.bitplan.com/)

# Opensource Projects
We contributed to and/or created the following OpenSource projects to reach our project goals:
* [Semantic MediaWiki](https://www.semantic-mediawiki.org/wiki/Semantic_MediaWiki)
* [ConfIDent dataimports](https://github.com/TIBHannover/confiDent-dataimports)
* [geograpy3](https://github.com/somnathrakshit/geograpy3)
* [py-3dparty-mediawiki](https://github.com/WolfgangFahl/py-3rdparty-mediawiki)
* [pyLodstorage](https://github.com/WolfgangFahl/pyLoDStorage)
* [dblpconf](https://pypi.org/project/dblpconf/)
* [aeon](https://github.com/tibonto/aeon)

==> OpenResearchMigration-0.0.4.tar.gz: OpenResearchMigration-0.0.4/README.md <==
[![Join the discussion](https://img.shields.io/badge/Discussion-OPENRESEARCH-brightgreen)](https://github.com/SmartDataAnalytics/OpenResearch/discussions)
[![GitHub issues](https://img.shields.io/github/issues/SmartDataAnalytics/OpenResearch.svg)](https://github.com/SmartDataAnalytics/OpenResearch/issues)
[![GitHub issues](https://img.shields.io/github/issues-closed/SmartDataAnalytics/OpenResearch.svg)](https://github.com/SmartDataAnalytics/OpenResearch/issues/?q=is%3Aissue+is%3Aclosed)
[![Website OPENRESEARCH](https://img.shields.io/website-up-down-green-red/https/www.openresearch.org.svg)](https://www.openresearch.org)
[![PyPI Status](https://img.shields.io/pypi/v/OpenResearchMigration.svg)](https://pypi.python.org/pypi/OpenResearchMigration/)
[![pypi](https://img.shields.io/pypi/pyversions/OpenResearchMigration)](https://pypi.org/project/OpenResearchMigration/)

# OPEN RESEARCH

This repository is mainly used as public ticket system for
[![OPENRESEARCH LOGO](https://www.openresearch.org/mediawiki/images/e/ed/Openresearch_logo_2017_rgb_resized.png)](https://www.openresearch.org/wiki/Main_Page)


# ConfIDent
[![ConfIDent Logo](https://projects.tib.eu/fileadmin/templates/confident/tib_projects_confident_1150.jpg)](https://www.openresearch.org)

## Public Links
* [OPENRESEARCH](https://www.openresearch.org)
* [ConfIDent Project Home page](https://projects.tib.eu/en/confident/)
* [ConfIDent Project page at TIB](https://www.tib.eu/en/research-development/project-overview/project-summary/confident)
* [RWTH Aachen i5 ConfIDent server](https://confident.dbis.rwth-aachen.de/)
* [TIB confident-conference.org](https://www.confident-conference.org/r/)

## Demos
* [Proceedings Title Parser](http://ptp.bitplan.com)
* [Semantified CEUR-WS](http://ceur-ws.bitplan.com/index.php/Main_Page)
* [Conferences and Location demo](https://cr.bitplan.com/index.php/Main_Page)
* [dblp xml conference import](https://confident.dbis.rwth-aachen.de/dblpconf/)

## Protected content
* [ConfIDent Requirements, Usecases and Design](https://rq.bitplan.com/)

# Opensource Projects
We contributed to and/or created the following OpenSource projects to reach our project goals:
* [Semantic MediaWiki](https://www.semantic-mediawiki.org/wiki/Semantic_MediaWiki)
* [ConfIDent dataimports](https://github.com/TIBHannover/confiDent-dataimports)
* [geograpy3](https://github.com/somnathrakshit/geograpy3)
* [py-3dparty-mediawiki](https://github.com/WolfgangFahl/py-3rdparty-mediawiki)
* [pyLodstorage](https://github.com/WolfgangFahl/pyLoDStorage)
* [dblpconf](https://pypi.org/project/dblpconf/)
* [aeon](https://github.com/tibonto/aeon)
